@@ -26,6 +26,7 @@
 #ifdef __linux__
 # include <sys/prctl.h>
 #endif
+#include <sys/resource.h>
 #include <unistd.h>
 
 #include "ptyxis-agent-compat.h"
@@ -891,11 +892,31 @@ ptyxis_run_context_callback_layer (PtyxisRunContext       *self,
   return ret;
 }
 
+static void
+set_max_fd_limit (gint64 value)
+{
+  struct rlimit limit;
+
+  if (value <= 0)
+    return;
+
+  if (getrlimit (RLIMIT_NOFILE, &limit) == 0)
+    {
+      limit.rlim_cur = value;
+
+      if (setrlimit (RLIMIT_NOFILE, &limit) != 0)
+        g_warning ("Failed to set FD limit to %"G_GSSIZE_FORMAT"",
+                   (gssize)value);
+    }
+}
+
 static void
 ptyxis_run_context_child_setup_cb (gpointer data)
 {
   gboolean setup_tty = GPOINTER_TO_INT (data);
 
+  set_max_fd_limit (ptyxis_agent_get_default_rlimit_nofile ());
+
   setsid ();
   setpgid (0, 0);
 
@@ -1114,12 +1135,15 @@ ptyxis_run_context_push_scope_cb (PtyxisRunContext    *self,
 
   if (has_systemd ())
     {
+      g_autofree char *uuid = g_uuid_string_random ();
+
       ptyxis_run_context_append_argv (self, "systemd-run");
       ptyxis_run_context_append_argv (self, "--user");
       ptyxis_run_context_append_argv (self, "--scope");
       ptyxis_run_context_append_argv (self, "--collect");
       ptyxis_run_context_append_argv (self, "--quiet");
       ptyxis_run_context_append_argv (self, "--same-dir");
+      ptyxis_run_context_append_formatted (self, "--unit=ptyxis-spawn-%s.scope", uuid);
     }
 
   ptyxis_run_context_append_args (self, argv);
