@@ -20,11 +20,13 @@
 
 #include "config.h"
 
+#include <errno.h>
 #include <sys/resource.h>
 
 #include <glib/gi18n.h>
 
 #include "ptyxis-application.h"
+#include "ptyxis-palette.h"
 #include "ptyxis-util.h"
 
 static gint64 default_rlimit_nofile;
@@ -35,9 +37,12 @@ check_early_opts (int        *argc,
                   gboolean   *standalone)
 {
   g_autoptr(GOptionContext) context = NULL;
+  g_autofree char *palette = NULL;
   gboolean version = FALSE;
   gboolean ignore_standalone = FALSE;
+  gboolean real_standalone = FALSE;
   GOptionEntry entries[] = {
+    { "import-palette", 0, 0, G_OPTION_ARG_FILENAME, &palette },
     { "standalone", 's', 0, G_OPTION_ARG_NONE, standalone },
     { "version", 0, 0, G_OPTION_ARG_NONE, &version },
     { NULL }
@@ -59,6 +64,9 @@ check_early_opts (int        *argc,
           (g_str_equal (arg, "--tab-with-profile") || g_str_has_prefix (arg, "--tab-with-profile=")))
         ignore_standalone = TRUE;
 
+      if (g_str_equal (arg, "-x") || g_str_equal (arg, "--execute") || g_str_has_prefix (arg, "--execute="))
+        real_standalone = TRUE;
+
       /* Convert -e to -- for x-terminal-emulator */
       if (strcmp (arg, "-e") == 0)
         arg[1] = '-';
@@ -80,13 +88,15 @@ check_early_opts (int        *argc,
           (*argv)[i] = g_strdup ("-x");
           (*argv)[i+1] = g_string_free (str, FALSE);
 
-          if (!ignore_standalone)
-            *standalone = TRUE;
+          real_standalone = TRUE;
 
           break;
         }
     }
 
+  if (!ignore_standalone && real_standalone)
+    *standalone = real_standalone;
+
   context = g_option_context_new (NULL);
   g_option_context_set_ignore_unknown_options (context, TRUE);
   g_option_context_set_help_enabled (context, FALSE);
@@ -112,6 +122,48 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 
       exit (EXIT_SUCCESS);
     }
+
+  /* We handle this here instead of in the main application so we can
+   * synchronously copy without blocking the main loop and also to not
+   * complicate the "activation" path that would normally need to
+   * happen in the remote instance.
+   */
+  if (palette != NULL)
+    {
+      g_autoptr(GError) error = NULL;
+      g_autofree char *contents = NULL;
+      g_autofree char *basename = g_path_get_basename (palette);
+      g_autofree char *user_palettes_dir = ptyxis_get_user_palettes_dir ();
+      g_autofree char *dest = g_build_filename (user_palettes_dir, basename, NULL);
+      gsize len;
+
+      if (!g_file_get_contents (palette, &contents, &len, &error))
+        {
+          g_printerr ("%s: %s\n", _("Error"), error->message);
+          exit (EXIT_FAILURE);
+        }
+
+      if (g_mkdir_with_parents (user_palettes_dir, 0750) != 0)
+        {
+          int errsv = errno;
+          g_printerr ("%s: %s\n", _("Error"), g_strerror (errsv));
+          exit (EXIT_FAILURE);
+        }
+
+      if (g_file_test (dest, G_FILE_TEST_EXISTS))
+        {
+          g_printerr (_("Error: %s already exists.\nPlease remove it first.\n"), dest);
+          exit (EXIT_FAILURE);
+        }
+
+      if (!g_file_set_contents (dest, contents, len, &error))
+        {
+          g_printerr ("%s: %s\n", _("Error"), error->message);
+          exit (EXIT_FAILURE);
+        }
+
+      exit (EXIT_SUCCESS);
+    }
 }
 
 static gint64
@@ -168,7 +220,7 @@ main (int   argc,
   check_early_opts (&argc, &argv, &standalone);
 
   if (standalone)
-    flags |= G_APPLICATION_NON_UNIQUE;
+    flags |= G_APPLICATION_NON_UNIQUE | G_APPLICATION_CAN_OVERRIDE_APP_ID;
 
   default_rlimit_nofile = get_current_fd_limit ();
   bump_to_max_fd_limit ();
