@@ -42,6 +42,7 @@ enum {
   PROP_DEFAULT_PROFILE_UUID,
   PROP_DISABLE_PADDING,
   PROP_ENABLE_A11Y,
+  PROP_IGNORE_OSC_TITLE,
   PROP_FONT_DESC,
   PROP_FONT_NAME,
   PROP_INTERFACE_STYLE,
@@ -58,6 +59,7 @@ enum {
   PROP_USE_SYSTEM_FONT,
   PROP_VISUAL_BELL,
   PROP_VISUAL_PROCESS_LEADER,
+  PROP_WORD_CHAR_EXCEPTIONS,
   N_PROPS
 };
 
@@ -112,6 +114,8 @@ ptyxis_settings_changed_cb (PtyxisSettings *self,
     g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_TOAST_ON_COPY_CLIPBOARD]);
   else if (g_str_equal (key, PTYXIS_SETTING_KEY_ENABLE_A11Y))
     g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_ENABLE_A11Y]);
+  else if (g_str_equal (key, PTYXIS_SETTING_KEY_IGNORE_OSC_TITLE))
+    g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_IGNORE_OSC_TITLE]);
   else if (g_str_equal (key, PTYXIS_SETTING_KEY_FONT_NAME))
     {
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_FONT_NAME]);
@@ -122,6 +126,8 @@ ptyxis_settings_changed_cb (PtyxisSettings *self,
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_USE_SYSTEM_FONT]);
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_FONT_DESC]);
     }
+  else if (g_str_equal (key, PTYXIS_SETTING_KEY_WORD_CHAR_EXCEPTIONS))
+    g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_WORD_CHAR_EXCEPTIONS]);
 }
 
 static void
@@ -168,6 +174,10 @@ ptyxis_settings_get_property (GObject    *object,
       g_value_set_boolean (value, ptyxis_settings_get_enable_a11y (self));
       break;
 
+    case PROP_IGNORE_OSC_TITLE:
+      g_value_set_boolean (value, ptyxis_settings_get_ignore_osc_title (self));
+      break;
+
     case PROP_FONT_DESC:
       g_value_take_boxed (value, ptyxis_settings_dup_font_desc (self));
       break;
@@ -267,6 +277,10 @@ ptyxis_settings_set_property (GObject      *object,
       ptyxis_settings_set_enable_a11y (self, g_value_get_boolean (value));
       break;
 
+    case PROP_IGNORE_OSC_TITLE:
+      ptyxis_settings_set_ignore_osc_title (self, g_value_get_boolean (value));
+      break;
+
     case PROP_FONT_NAME:
       ptyxis_settings_set_font_name (self, g_value_get_string (value));
       break;
@@ -346,14 +360,14 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
   object_class->set_property = ptyxis_settings_set_property;
 
   properties[PROP_AUDIBLE_BELL] =
-    g_param_spec_boolean ("audible-bell", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_AUDIBLE_BELL, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_CURSOR_BLINK_MODE] =
-    g_param_spec_enum ("cursor-blink-mode", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_CURSOR_BLINK_MODE, NULL, NULL,
                        VTE_TYPE_CURSOR_BLINK_MODE,
                        VTE_CURSOR_BLINK_SYSTEM,
                        (G_PARAM_READWRITE |
@@ -361,7 +375,7 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_CURSOR_SHAPE] =
-    g_param_spec_enum ("cursor-shape", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_CURSOR_SHAPE, NULL, NULL,
                        VTE_TYPE_CURSOR_SHAPE,
                        VTE_CURSOR_SHAPE_BLOCK,
                        (G_PARAM_READWRITE |
@@ -369,7 +383,14 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_ENABLE_A11Y] =
-    g_param_spec_boolean ("enable-a11y", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_ENABLE_A11Y, NULL, NULL,
+                          FALSE,
+                          (G_PARAM_READWRITE |
+                           G_PARAM_EXPLICIT_NOTIFY |
+                           G_PARAM_STATIC_STRINGS));
+
+  properties[PROP_IGNORE_OSC_TITLE] =
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_IGNORE_OSC_TITLE, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
@@ -383,14 +404,14 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                          G_PARAM_STATIC_STRINGS));
 
   properties[PROP_FONT_NAME] =
-    g_param_spec_string ("font-name", NULL, NULL,
+    g_param_spec_string (PTYXIS_SETTING_KEY_FONT_NAME, NULL, NULL,
                          NULL,
                          (G_PARAM_READWRITE |
                           G_PARAM_EXPLICIT_NOTIFY |
                           G_PARAM_STATIC_STRINGS));
 
   properties[PROP_INTERFACE_STYLE] =
-    g_param_spec_enum ("interface-style", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_INTERFACE_STYLE, NULL, NULL,
                        ADW_TYPE_COLOR_SCHEME,
                        ADW_COLOR_SCHEME_DEFAULT,
                        (G_PARAM_READWRITE |
@@ -398,7 +419,7 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_NEW_TAB_POSITION] =
-    g_param_spec_enum ("new-tab-position", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_NEW_TAB_POSITION, NULL, NULL,
                        PTYXIS_TYPE_NEW_TAB_POSITION,
                        PTYXIS_NEW_TAB_POSITION_LAST,
                        (G_PARAM_READWRITE |
@@ -406,55 +427,55 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_DEFAULT_PROFILE_UUID] =
-    g_param_spec_string ("default-profile-uuid", NULL, NULL,
+    g_param_spec_string (PTYXIS_SETTING_KEY_DEFAULT_PROFILE_UUID, NULL, NULL,
                          NULL,
                          (G_PARAM_READWRITE |
                           G_PARAM_EXPLICIT_NOTIFY |
                           G_PARAM_STATIC_STRINGS));
 
   properties[PROP_DISABLE_PADDING] =
-    g_param_spec_boolean ("disable-padding", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_DISABLE_PADDING, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_PROFILE_UUIDS] =
-    g_param_spec_boxed ("profile-uuids", NULL, NULL,
+    g_param_spec_boxed (PTYXIS_SETTING_KEY_PROFILE_UUIDS, NULL, NULL,
                         G_TYPE_STRV,
                         (G_PARAM_READABLE |
                          G_PARAM_STATIC_STRINGS));
 
   properties[PROP_RESTORE_SESSION] =
-    g_param_spec_boolean ("restore-session", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_RESTORE_SESSION, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_RESTORE_WINDOW_SIZE] =
-    g_param_spec_boolean ("restore-window-size", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_RESTORE_WINDOW_SIZE, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_DEFAULT_COLUMNS] =
-    g_param_spec_uint ("default-columns", NULL, NULL,
+    g_param_spec_uint (PTYXIS_SETTING_KEY_DEFAULT_COLUMNS, NULL, NULL,
                        1, 65535, 80,
                        (G_PARAM_READWRITE |
                         G_PARAM_EXPLICIT_NOTIFY |
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_DEFAULT_ROWS] =
-    g_param_spec_uint ("default-rows", NULL, NULL,
+    g_param_spec_uint (PTYXIS_SETTING_KEY_DEFAULT_ROWS, NULL, NULL,
                        1, 65535, 24,
                        (G_PARAM_READWRITE |
                         G_PARAM_EXPLICIT_NOTIFY |
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_SCROLLBAR_POLICY] =
-    g_param_spec_enum ("scrollbar-policy", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_SCROLLBAR_POLICY, NULL, NULL,
                        PTYXIS_TYPE_SCROLLBAR_POLICY,
                        PTYXIS_SCROLLBAR_POLICY_SYSTEM,
                        (G_PARAM_READWRITE |
@@ -462,7 +483,7 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_TAB_MIDDLE_CLICK] =
-    g_param_spec_enum ("tab-middle-click", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_TAB_MIDDLE_CLICK, NULL, NULL,
                        PTYXIS_TYPE_TAB_MIDDLE_CLICK_BEHAVIOR,
                        PTYXIS_TAB_MIDDLE_CLICK_CLOSE,
                        (G_PARAM_READWRITE |
@@ -470,7 +491,7 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_TEXT_BLINK_MODE] =
-    g_param_spec_enum ("text-blink-mode", NULL, NULL,
+    g_param_spec_enum (PTYXIS_SETTING_KEY_TEXT_BLINK_MODE, NULL, NULL,
                        VTE_TYPE_TEXT_BLINK_MODE,
                        VTE_TEXT_BLINK_ALWAYS,
                        (G_PARAM_READWRITE |
@@ -478,33 +499,40 @@ ptyxis_settings_class_init (PtyxisSettingsClass *klass)
                         G_PARAM_STATIC_STRINGS));
 
   properties[PROP_TOAST_ON_COPY_CLIPBOARD] =
-    g_param_spec_boolean ("toast-on-copy-clipboard", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_TOAST_ON_COPY_CLIPBOARD, NULL, NULL,
                           TRUE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_USE_SYSTEM_FONT] =
-    g_param_spec_boolean ("use-system-font", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_USE_SYSTEM_FONT, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_VISUAL_BELL] =
-    g_param_spec_boolean ("visual-bell", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_VISUAL_BELL, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
   properties[PROP_VISUAL_PROCESS_LEADER] =
-    g_param_spec_boolean ("visual-process-leader", NULL, NULL,
+    g_param_spec_boolean (PTYXIS_SETTING_KEY_VISUAL_PROCESS_LEADER, NULL, NULL,
                           FALSE,
                           (G_PARAM_READWRITE |
                            G_PARAM_EXPLICIT_NOTIFY |
                            G_PARAM_STATIC_STRINGS));
 
+  properties[PROP_WORD_CHAR_EXCEPTIONS] =
+    g_param_spec_string (PTYXIS_SETTING_KEY_WORD_CHAR_EXCEPTIONS, NULL, NULL,
+                         NULL,
+                         (G_PARAM_READWRITE |
+                          G_PARAM_EXPLICIT_NOTIFY |
+                          G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_properties (object_class, N_PROPS, properties);
 }
 
@@ -1065,3 +1093,54 @@ ptyxis_settings_get_disable_padding (PtyxisSettings *self)
   return g_settings_get_boolean (self->settings,
                                  PTYXIS_SETTING_KEY_DISABLE_PADDING);
 }
+
+char *
+ptyxis_settings_dup_word_char_exceptions (PtyxisSettings *self)
+{
+  char *word_char_exceptions;
+
+  g_return_val_if_fail (PTYXIS_IS_SETTINGS (self), NULL);
+
+  g_settings_get (self->settings, PTYXIS_SETTING_KEY_WORD_CHAR_EXCEPTIONS, "ms", &word_char_exceptions);
+  return word_char_exceptions;
+}
+
+void
+ptyxis_settings_set_prompt_on_close (PtyxisSettings *self,
+                                     gboolean        prompt_on_close)
+{
+  g_return_if_fail (PTYXIS_IS_SETTINGS (self));
+
+  g_settings_set_boolean (self->settings,
+                          PTYXIS_SETTING_KEY_PROMPT_ON_CLOSE,
+                          !!prompt_on_close);
+}
+
+gboolean
+ptyxis_settings_get_prompt_on_close (PtyxisSettings *self)
+{
+  g_return_val_if_fail (PTYXIS_IS_SETTINGS (self), FALSE);
+
+  return g_settings_get_boolean (self->settings,
+                                 PTYXIS_SETTING_KEY_PROMPT_ON_CLOSE);
+}
+
+void
+ptyxis_settings_set_ignore_osc_title (PtyxisSettings *self,
+                                      gboolean        ignore_osc_title)
+{
+  g_return_if_fail (PTYXIS_IS_SETTINGS (self));
+
+  g_settings_set_boolean (self->settings,
+                          PTYXIS_SETTING_KEY_IGNORE_OSC_TITLE,
+                          !!ignore_osc_title);
+}
+
+gboolean
+ptyxis_settings_get_ignore_osc_title (PtyxisSettings *self)
+{
+  g_return_val_if_fail (PTYXIS_IS_SETTINGS (self), FALSE);
+
+  return g_settings_get_boolean (self->settings,
+                                 PTYXIS_SETTING_KEY_IGNORE_OSC_TITLE);
+}
